import {} from './RequestSenderInterface.js';
export class HttpRequestSender {
    /**
     * Sends a HTTP request to a given URL.
     *
     * @param {string} url - The endpoint URL
     * @param {RequestInit} options - The request options (method, headers, body, etc.)
     * @returns {Promise<Response>} - A promise that resolves to the response
     */
    async send(url, options = {}) {
        console.log('Sending request to URL:', url);
        console.log('Request options:', JSON.stringify(options, null, 2));
        return fetch(url, {
            ...options
        })
            .catch(error => {
            console.error('Failed to send request:', JSON.stringify(error, null, 2));
            // Handle the exception and return a custom Response object
            const responseInit = {
                status: 500,
                statusText: error.message
            };
            // Return a Response object with an appropriate error message
            return new Response(null, responseInit);
        })
            .then(async (response) => {
            console.log('Received response status:', response.status);
            // Log the response body if it's JSON
            const contentType = response.headers.get('content-type');
            if (contentType && contentType.includes('application/json')) {
                const responseClone = response.clone();
                const responseBody = await responseClone.json().catch(() => { response.text(); });
                console.log('Received response body:', JSON.stringify(responseBody, null, 2));
            }
            else if (contentType && contentType.includes('text/plain')) {
                const responseClone = response.clone();
                const responseBody = await responseClone.text();
                console.log('Received response body:', responseBody);
            }
            return response;
        });
    }
}
